fn process_flat_map_row<T>(
input_row: &RowRef,
time: &T,
diff: &Diff,
exprs: &[LirScalarExpr],
func: &TableFunc,
mfp_plan: &MfpPlan<LirScalarExpr>,
until: &Antichain<Timestamp>,
datums: &mut DatumVec,
datums_mfp: &mut DatumVec,
table_func_output: &mut Vec<(Row, Diff)>,
ok_session: &mut Session<'_, '_, T, ConsolidatingColumnBuilder<Row, T, Diff>, Capability<T>>,
err_session: &mut Session<'_, '_, T, ConsolidatingContainerBuilder<Vec<(DataflowErrorSer, T, Diff)>>, Capability<T>>,
budget: &mut usize,
)where
T: RenderTimestamp,Expand description
Expands one input record’s table function and drains it through the mfp.
The expansion is chunked so drain_through_mfp amortizes the input-row decode.
Argument or function evaluation errors emit to the err session and return early.